PIconnect documentation
=======================

A python connector to the OSISoft PI and PI-AF databases

This connector allows access to the OSISoft PI System through their
proprietary SDK. It provides a number of classes, mostly mirroring the AF SDK
structure, but at the same time implementing the cool stuff we use Python for.

The documentation for :py:mod:`PIconnect` is roughly structured according to
`Daniele Procida's <https://www.divio.com/blog/documentation/>`_ proposed
structure:

- The basic introductions to using :py:mod:`PIconnect` are covered in the
  :doc:`/tutorials`.
- The technical reference to all modules within :py:mod:`PIconnect` are
  covered in :doc:`/api/index`. These also include several links to the original
  SDK documentation for important implementation details.
- Background explanations and how-to guides still need to be written.

Contents
--------

.. toctree::
   :maxdepth: 2

   installation
   tutorials
   api/index
   contributing
   authors
   history
   copyright
   todo


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
